[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
34/42: gnu: emacs-org-super-agenda: Use G-expressions.
From: |
guix-commits |
Subject: |
34/42: gnu: emacs-org-super-agenda: Use G-expressions. |
Date: |
Tue, 3 Oct 2023 16:54:51 -0400 (EDT) |
ngz pushed a commit to branch master
in repository guix.
commit cc09b0ebfe9df79efd73130f221ec53560638840
Author: Nicolas Goaziou <mail@nicolasgoaziou.fr>
AuthorDate: Tue Oct 3 21:32:40 2023 +0200
gnu: emacs-org-super-agenda: Use G-expressions.
* gnu/packages/emacs-xyz.scm (emacs-org-super-agenda)[arguments]: Use
G-expressions.
---
gnu/packages/emacs-xyz.scm | 29 +++++++++++++++--------------
1 file changed, 15 insertions(+), 14 deletions(-)
diff --git a/gnu/packages/emacs-xyz.scm b/gnu/packages/emacs-xyz.scm
index f2d65a79fc..54a57951bf 100644
--- a/gnu/packages/emacs-xyz.scm
+++ b/gnu/packages/emacs-xyz.scm
@@ -22540,20 +22540,21 @@ for defining recurring tasks and easily scheduling
them.")
(base32 "07fv4zgmfc8ppppbr7ylhx89wcw6r6vmz4a6pg0iy4v7sn5pp1wa"))))
(build-system emacs-build-system)
(arguments
- `(#:tests? #true
- #:test-command '("test/run" "--debug")
- #:phases
- (modify-phases %standard-phases
- (add-after 'unpack 'prepare-for-tests.el
- (lambda _
- (make-file-writable "test/test.el")
- (emacs-substitute-variables "test/test.el"
- ("org-super-agenda-test-results-file"
- (string-append (getcwd) "/test/results.el")))
- ;; The following tests fail.
- (substitute* "test/test.el"
- ((".* org-super-agenda-test--with-retained-sorting .*" all)
- (string-append all " (skip-unless nil)\n"))))))))
+ (list
+ #:tests? #true
+ #:test-command #~(list "test/run" "--debug")
+ #:phases
+ #~(modify-phases %standard-phases
+ (add-after 'unpack 'prepare-for-tests.el
+ (lambda _
+ (make-file-writable "test/test.el")
+ (emacs-substitute-variables "test/test.el"
+ ("org-super-agenda-test-results-file"
+ (string-append (getcwd) "/test/results.el")))
+ ;; The following tests fail.
+ (substitute* "test/test.el"
+ ((".* org-super-agenda-test--with-retained-sorting .*" all)
+ (string-append all " (skip-unless nil)\n"))))))))
(native-inputs
(list emacs-f util-linux))
(propagated-inputs
- 28/42: gnu: emacs-mct: Update to 1.0.0., (continued)
- 28/42: gnu: emacs-mct: Update to 1.0.0., guix-commits, 2023/10/03
- 32/42: gnu: emacs-org-super-agenda: Update to 1.3., guix-commits, 2023/10/03
- 33/42: gnu: emacs-org-super-agenda: Run tests., guix-commits, 2023/10/03
- 36/42: gnu: emacs-pg: Update to 0.24., guix-commits, 2023/10/03
- 37/42: gnu: emacs-tree-inspector: Update to 0.4., guix-commits, 2023/10/03
- 15/42: gnu: emacs-dracula-theme: Update to 1.8.1., guix-commits, 2023/10/03
- 14/42: gnu: emacs-datetime: Update to 0.9.1., guix-commits, 2023/10/03
- 39/42: gnu: emacs-yaml: Update to 0.5.4., guix-commits, 2023/10/03
- 19/42: gnu: emacs-embark: Update to 0.23., guix-commits, 2023/10/03
- 22/42: gnu: emacs-fountain-mode: Update to 3.6.3., guix-commits, 2023/10/03
- 34/42: gnu: emacs-org-super-agenda: Use G-expressions.,
guix-commits <=
- 35/42: gnu: emacs-parseedn: Update to 1.2.0., guix-commits, 2023/10/03
- 38/42: gnu: emacs-web-mode: Update to 17.3.13., guix-commits, 2023/10/03
- 29/42: gnu: emacs-modus-themes: Update to 4.3.0., guix-commits, 2023/10/03
- 40/42: gnu: emacs-yeetube: Update to 2.0.4., guix-commits, 2023/10/03
- 30/42: gnu: emacs-org-ql: Update to 0.7.2., guix-commits, 2023/10/03
- 41/42: gnu: emacs-yeetube: Use executables from inputs., guix-commits, 2023/10/03
- 42/42: gnu: emacs-yeetube: Improve package style., guix-commits, 2023/10/03